@@ -112,14 +112,6 @@ class Debug(Cog, name="debug"):
                     return False
         return not self.bot._paused
 
-    @command()
-    async def t(self, ctx):
-        print(".")
-
-    @command()
-    async def e(self, ctx):
-        print(".")
-
     @command(hidden=True)
     async def debug(self, ctx):
         """
