@@ -1,11 +1,12 @@
 from typing import List
 from disnake_paginator import ButtonPaginator
 from fuzzywuzzy import fuzz
-from ..utils import EMBED_COLOR, EmbedFactory, MainMenu, get_bot_message
+from ..utils import EmbedFactory, MainMenu, get_bot_message
+from ..constants import EMBED_COLOR
 
 from disnake import Message, MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
-from disnake.ext.commands import Context
+from disnake.ext.commands import Context, Bot
 
 
 def pretty(invokes: List[dict]) -> List[str]:
@@ -36,13 +37,13 @@ class FindInvoke(View):
         super().__init__()
 
         self.ctx = ctx
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
         self.add_item(MainMenu(ctx))
 
     def check(self, m: Message) -> bool:
         return m.author == self.ctx.author and m.channel == self.ctx.channel
-        
+
     async def interaction_check(self, interaction: MessageInteraction) -> bool:
         return (
             interaction.author == self.ctx.author
@@ -60,7 +61,13 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -93,7 +100,13 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -126,7 +139,13 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -159,7 +178,10 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -192,7 +214,10 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -228,7 +253,10 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"True/False?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -264,7 +292,10 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"True/False?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -301,7 +332,10 @@ class FindInvoke(View):
             f"What was the command {name}?", ephemeral=True
         )
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -336,7 +370,10 @@ class FindInvoke(View):
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message(f"What {name}?", ephemeral=True)
 
-        message = await self.bot.wait_for("message", check=self.check)
+        message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         output = find(self.bot._commands_ran, key=name, value=message.content)
 
         if not output:
@@ -368,7 +405,7 @@ class Invokes(View):
         super().__init__()
 
         self.ctx = ctx
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
         self.add_item(MainMenu(ctx))
 
